Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4827)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java

Issue 1739523002: WebUsb Android chooser UI (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase and added NoUnderlineClickableSpan.java to ui/android/BUILD.gn Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java
index 16b307a370b04ddaee34b71f1dfe5bd462cb9639..2e555f5daecc66d3b2f6fdfedeea20178a588579 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/BluetoothChooserDialogTest.java
@@ -140,12 +140,13 @@ public class BluetoothChooserDialogTest extends ChromeActivityTestCaseBase<Chrom
}
/**
* The messages include <link> ... </link> sections that are used to create
* clickable spans. For testing the messages, this function returns the raw
* string without the tags.
*/
private static String removeLinkTags(String message) {
- return message.replaceAll("</?link>", "");
+ return message.replaceAll("</?link1>", "").replaceAll(
+ "</?link2>", "").replaceAll("</?link>", "");
}
@SmallTest
@@ -202,7 +203,8 @@ public class BluetoothChooserDialogTest extends ChromeActivityTestCaseBase<Chrom
// the progress spinner should disappear, the Commit button should still
// be disabled (since nothing's selected), and the list view should
// show.
- assertEquals(removeLinkTags(getActivity().getString(R.string.bluetooth_not_seeing_it)),
+ assertEquals(removeLinkTags(getActivity().getString(
+ R.string.bluetooth_not_seeing_it_idle_some_found)),
statusView.getText().toString());
assertFalse(button.isEnabled());
assertEquals(View.VISIBLE, items.getVisibility());
@@ -140,12 +140,13 @@ public class BluetoothChooserDialogTest extends ChromeActivityTestCaseBase<Chrom
}
/**
- * The messages include <link> ... </link> sections that are used to create
- * clickable spans. For testing the messages, this function returns the raw
- * string without the tags.
+ * The messages include <link> ... </link> or <link1> ... </link1>, <link2> ... </link2>
+ * sections that are used to create clickable spans. For testing the messages, this function
+ * returns the raw string without the tags.
*/
private static String removeLinkTags(String message) {

Powered by Google App Engine
This is Rietveld 408576698